.. Publication Tracker documentation master file, created by
   sphinx-quickstart on Fri Oct  8 00:10:07 2021.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to Academic Tracker's Documentation!
============================================

.. include:: ../README.rst

Documentation index:
====================

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   guide
   tutorial
   jsonschema
   reporting
   tokenization
   api
   license
   todo


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
